==> bonita-server-6.3.7-sources.jar: org/bonitasoft/engine/search/task/SearchAssignedAndPendingHumanTasksFor.java <==
/**
 * Copyright (C) 2014 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.search.task;

import java.util.List;

import org.bonitasoft.engine.core.process.instance.api.ActivityInstanceService;
import org.bonitasoft.engine.core.process.instance.model.SHumanTaskInstance;
import org.bonitasoft.engine.execution.state.FlowNodeStateManager;
import org.bonitasoft.engine.persistence.QueryOptions;
import org.bonitasoft.engine.persistence.SBonitaSearchException;
import org.bonitasoft.engine.search.AbstractHumanTaskInstanceSearchEntity;
import org.bonitasoft.engine.search.SearchOptions;
import org.bonitasoft.engine.search.descriptor.SearchHumanTaskInstanceDescriptor;

/**
 * @author Celine Souchet
 */
public class SearchAssignedAndPendingHumanTasksFor extends AbstractHumanTaskInstanceSearchEntity {

    private final ActivityInstanceService activityInstanceService;

    private final long userId;

    private final long rootProcessDefinitionId;

    public SearchAssignedAndPendingHumanTasksFor(final ActivityInstanceService activityInstanceService, final FlowNodeStateManager flowNodeStateManager,
            final SearchHumanTaskInstanceDescriptor searchEntitiesDescriptor, final long rootProcessDefinitionId, final long userId, final SearchOptions options) {
        super(searchEntitiesDescriptor, options, flowNodeStateManager);
        this.activityInstanceService = activityInstanceService;
        this.rootProcessDefinitionId = rootProcessDefinitionId;
        this.userId = userId;
    }

    @Override
    public long executeCount(final QueryOptions queryOptions) throws SBonitaSearchException {
        return activityInstanceService.getNumberOfAssignedAndPendingHumanTasksFor(rootProcessDefinitionId, userId, queryOptions);
    }

    @Override
    public List<SHumanTaskInstance> executeSearch(final QueryOptions queryOptions) throws SBonitaSearchException {
        return activityInstanceService.searchAssignedAndPendingHumanTasksFor(rootProcessDefinitionId, userId, queryOptions);
    }

}

==> bonita-server-6.5.0-sources.jar: org/bonitasoft/engine/search/task/SearchAssignedAndPendingHumanTasksFor.java <==
/**
 * Copyright (C) 2014 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.search.task;

import java.util.List;

import org.bonitasoft.engine.core.process.instance.api.ActivityInstanceService;
import org.bonitasoft.engine.core.process.instance.model.SHumanTaskInstance;
import org.bonitasoft.engine.execution.state.FlowNodeStateManager;
import org.bonitasoft.engine.persistence.QueryOptions;
import org.bonitasoft.engine.persistence.SBonitaReadException;
import org.bonitasoft.engine.search.AbstractHumanTaskInstanceSearchEntity;
import org.bonitasoft.engine.search.SearchOptions;
import org.bonitasoft.engine.search.descriptor.SearchHumanTaskInstanceDescriptor;

/**
 * @author Celine Souchet
 */
public class SearchAssignedAndPendingHumanTasksFor extends AbstractHumanTaskInstanceSearchEntity {

    private final ActivityInstanceService activityInstanceService;

    private final long userId;

    private final long rootProcessDefinitionId;

    public SearchAssignedAndPendingHumanTasksFor(final ActivityInstanceService activityInstanceService, final FlowNodeStateManager flowNodeStateManager,
            final SearchHumanTaskInstanceDescriptor searchEntitiesDescriptor, final long rootProcessDefinitionId, final long userId, final SearchOptions options) {
        super(searchEntitiesDescriptor, options, flowNodeStateManager);
        this.activityInstanceService = activityInstanceService;
        this.rootProcessDefinitionId = rootProcessDefinitionId;
        this.userId = userId;
    }

    @Override
    public long executeCount(final QueryOptions queryOptions) throws SBonitaReadException {
        return activityInstanceService.getNumberOfAssignedAndPendingHumanTasksFor(rootProcessDefinitionId, userId, queryOptions);
    }

    @Override
    public List<SHumanTaskInstance> executeSearch(final QueryOptions queryOptions) throws SBonitaReadException {
        return activityInstanceService.searchAssignedAndPendingHumanTasksFor(rootProcessDefinitionId, userId, queryOptions);
    }

}
